---
name: ✨ 功能建議
about: 為此專案建議一個想法
title: '[Feature] '
labels: enhancement
assignees: ''
---

## 這個功能建議是否與某個問題相關？
清楚簡潔地描述問題是什麼。例如：「每次 [...] 時我都很沮喪」

## 描述你想要的解決方案
清楚簡潔地描述你希望發生什麼。

## 描述你考慮過的替代方案
清楚簡潔地描述你考慮過的任何替代解決方案或功能。

## 使用場景
描述這個功能會在什麼情況下被使用。

## 額外備註
關於此功能建議的任何其他資訊或截圖。
